import os
from nameko.extensions import DependencyProvider


class DjangoModels(DependencyProvider):
    def setup(self):
        """Initialize the dependency"""
        import django
        if os.environ.get('DJANGO_NAMEKO_STANDALONE_SETTINGS_MODULE'):
            os.environ.setdefault("DJANGO_SETTINGS_MODULE", os.environ.get('DJANGO_NAMEKO_STANDALONE_SETTINGS_MODULE'))
        elif not os.environ.get('DJANGO_SETTINGS_MODULE'):
            os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")
        django.setup()

    def get_dependency(self, worker_ctx):
        """Get the dependency for the concrete service"""
        from django.apps import apps
        from django.conf import settings

        apps_config = map(apps.get_app_config, settings.DJANGO_NAMEKO_STANDALONE_APPS)
        models = type('NonExistingClass_', (), {})

        for config in apps_config:
            for model in config.get_models():
                setattr(models, model.__name__, model)
        return models

    def worker_teardown(self, worker_ctx):
        """Close all the connections on teardown

        TODO: Autocommit??
        """
        from django.db import connections
        connections.close_all()


__all__ = ["DjangoModels"]



import setuptools

with open('README.txt') as file:
    long_description = file.read()

setuptools.setup(
    name="django-nameko-standalone",
    version="1.2.2",
    author="Jesus Gutierrez Almazan",
    author_email="jesus.pedro.gutierrez.almazan@gmail.com",
    description="Use django into a nameko service",
    long_description=long_description,
    url="https://github.com/jesusenlanet/django-nameko-standalone",
    packages=['django_nameko_standalone'],
    platforms=['Linux'],
    install_requires=[
        "Django>=1.11,<=2.2.2",
        "nameko==2.12.0"
    ],
    test_suite='pytest',
    setup_requires=['pytest-runner'],
    tests_require=[
        'pytest',
    ],
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3.6",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
        "Framework :: Django :: 2.1",
        "Topic :: Software Development :: Libraries",
    ],
)
